%This file creates a .log file with random parameters, then runs Plaxis 2D
%AE with the .log file. Then it writes certain material data and the factor
%of safety to a result file.
%Made with help and guidance from Ivan Depina
%**********************************************************************

%Del 1
%Creating .log file with random parameters
Start = 1;
Slutt = 3;

FS=1;%Choose initial value for FS

%Writes FS to a result fil that contains all results       
%Define the file directory
Out=fullfile('D:\\Skole\\Var 2014\\PlaxisCommands\\Markov Chain MC\\MCMCResults\\samlet.txt');
        
%Open the file
[fout1,errmsg]=fopen(Out,'w');

%Check if the file is not open
if(fout1<0);
sprintf('Filen Kan ikke pnes, Dvven du e drlig (Outputfil)');
sprintf('Error Message. %s', errmsg);
end

for i=Start:Slutt
    FileOut=['D:\Skole\Var 2014\PlaxisCommands\Markov Chain MC\calculate' sprintf('%4.4d',i) '.log']; %definerer output fil
   
    %Random variable for SU *********************************************
    %Sets mean and standard deviation for SU
    m1=38.9; %Toppleire/ Top Clay
    s1=16.5;
    m2=32.2; %Blt Leire/ Soft Clay
    s2=14.8;
    m3=62.6; %Fast Leire/ Firm Clay
    s3=24.4;
    
    %Lognormal distribution:    
    %Toppleire/ Top Clay
    mu1=log((m1^2)/sqrt(s1^2+m1^2));
    sig1=sqrt(log(s1^2/m1^2+1));
    SU1=lognrnd(mu1,sig1);
    %Blt Leire/ Soft Clay
    mu2=log((m2^2)/sqrt(s2^2+m2^2));
    sig2=sqrt(log(s2^2/m2^2+1));
    SU2=lognrnd(mu2,sig2);
    %Fast Leire/ Firm Clay
    mu3=log((m3^2)/sqrt(s3^2+m3^2));
    sig3=sqrt(log(s3^2/m3^2+1));
    SU3=lognrnd(mu3,sig1);
            
    %Random variable for Anisotropy **********************************************
    %Uniform distribution
    PAS=(0.3+abs(0.15*rand(1,1)));
    DSS=(0.5+PAS/2);
    
    %Random variable for weight density (gamma)**********************************
    %Normal distribution
    mt1= 20; %Toppleire/ TOp Clay
    st1= 0.5;
    mt2= 20.1; %Blt Leire/ Soft Clay
    st2= 0.2;
    mt3= 20; %Fast Leire/ Firm Clay
    st3= 0.8;
    
    TT1= mt1+randn(1,1)*st1; %Weight density, Top Clay
    TT2= mt2+randn(1,1)*st2; %Weight Density, Soft Clay
    TT3= mt3+randn(1,1)*st3; %Weight density, Firm Clay
    
    
    %Open outputfile
    [fout,errmsg]=fopen(FileOut,'wt');
    
    %Check if file is not open
    if(fout<0);
        sprintf('Filen er ikke pen');
        sprintf('Error Message. %s', errmsg);
    end
    
    %Check if file is open
    if(fout>=0);
        
        %Endring av verdier for de tre verste lagene. sprintf() er
        %benyttet for  sette inn verdier p riktig plass
        %Changing of SU, DSS, (PAS)sive og Weight Density(TT)
        %for the three layers, Top Clay, Soft Clay and Firm Clay
           fprintf(fout,['sps Toppleire "Comments" "" "MaterialName" "Toppleire" "Colour" 10676870 "MaterialNumber" 0 "SoilModel" 9 "UserDefinedIndex" 0 "DrainageType" 2 "DilatancyCutOff" False "UndrainedBehaviour" 0 "InterfaceStrength" 0 "ConsiderGapClosure" True "K0PrimaryIsK0Secondary" True "K0Determination" 0 "DefaultValuesAdvanced" True "DataSetFlow" 0 "ModelFlow" 0 "UDModelFlow" 0 "SoilTypeFlow" 0 "LowerUpper" 0 "UsdaSoilType" 0 "StaringUpperSoilType" 0 "StaringLowerSoilType" 0 "M50" 0 "DefaultValuesFlow" False "TablePsiPermSat" "[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]" "SplinePsiPerm" "[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]" "SplinePsiSat" "[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]" 13554.6 0.3 0 ' sprintf('%d',SU1) ' 0 0.1 0 0 ' sprintf('%d',TT1) ' ' sprintf('%d',TT1) ' 0 0 1 0 0 0 0 0 0 0.333333333333333 0 0.999 0 0 0 0 1.00000000000000000E+015 0.495 0 0 300 0.99 0 0 0 ' sprintf('%d',DSS) ' ' sprintf('%d',PAS) ' 0.7 0.666666666666667 2.4 3.33333333333333 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 1 1 1 0 0 -1.06 -2.37 0 0 10000 1 0.0620347394540943 3.83 1.3774 1.25 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0\n']);
           fprintf(fout,['sps BltLeire "Comments" "" "MaterialName" "Blt leire" "Colour" 9664513 "MaterialNumber" 0 "SoilModel" 9 "UserDefinedIndex" 0 "DrainageType" 2 "DilatancyCutOff" False "UndrainedBehaviour" 0 "InterfaceStrength" 0 "ConsiderGapClosure" True "K0PrimaryIsK0Secondary" True "K0Determination" 1 "DefaultValuesAdvanced" True "DataSetFlow" 0 "ModelFlow" 0 "UDModelFlow" 0 "SoilTypeFlow" 0 "LowerUpper" 0 "UsdaSoilType" 0 "StaringUpperSoilType" 0 "StaringLowerSoilType" 0 "M50" 0 "DefaultValuesFlow" False "TablePsiPermSat" "[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]" "SplinePsiPerm" "[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]" "SplinePsiSat" "[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]" 3851.13 0.3 0 ' sprintf('%d',SU2) ' 0 0.1 0 0 ' sprintf('%d',TT2) ' ' sprintf('%d',TT2) ' 0 0 1 0 0 0 0 0 0 0.333333333333333 0 0.999 0 0 0 0 1.00000000000000000E+015 0.495 0 0 200 0.99 0 0 0 ' sprintf('%d',DSS) ' ' sprintf('%d',PAS) ' 0.7 0.666666666666667 2.4 3.33333333333333 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 1.00000000000000000E+010 1.00000000000000000E+010 1 0 0 -1.06 -2.37 0 0 10000 1 0.0620347394540943 3.83 1.3774 1.25 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0\n']);
           fprintf(fout,['sps FastLeire "Comments" "" "MaterialName" "Fast Leire" "Colour" 10602216 "MaterialNumber" 0 "SoilModel" 9 "UserDefinedIndex" 0 "DrainageType" 2 "DilatancyCutOff" False "UndrainedBehaviour" 0 "InterfaceStrength" 0 "ConsiderGapClosure" True "K0PrimaryIsK0Secondary" True "K0Determination" 0 "DefaultValuesAdvanced" True "DataSetFlow" 0 "ModelFlow" 0 "UDModelFlow" 0 "SoilTypeFlow" 0 "LowerUpper" 0 "UsdaSoilType" 0 "StaringUpperSoilType" 0 "StaringLowerSoilType" 0 "M50" 0 "DefaultValuesFlow" False "TablePsiPermSat" "[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]" "SplinePsiPerm" "[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]" "SplinePsiSat" "[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]" 11110 0.3 0 ' sprintf('%d',SU3) ' 0 0.1 0 0 ' sprintf('%d',TT3) ' ' sprintf('%d',TT3) ' 0 0 1 0 0 0 0 0 0 0.333333333333333 0 0.999 0 0 0 0 1.00000000000000000E+015 0.495 0 0 300 0.99 0 0 0 ' sprintf('%d',DSS) ' ' sprintf('%d',PAS) ' 0.7 0.666666666666667 2.4 3.33333333333333 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 1 1 1 0 0 -1.06 -2.37 0 0 10000 1 0.0620347394540943 3.83 1.3774 1.25 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0\n']);
           
         

        
        %PLAXIS commands to start calculations:
        fprintf(fout,'gotostages\n');     %Gr til stages
        fprintf(fout,'set InitialPhase.ShouldCalculate True\n'); %gjr at InitialPhase regnes ut
        fprintf(fout,'set Phase_1.ShouldCalculate True\n');      %gjr at Phase_1 regnes ut
        fprintf(fout,'Calculate\n'); %gjr at beregningene starter
        fprintf(fout,'Save\n'); %Lagrer prosjektet
        fprintf(fout,'__Kill\n'); %lukker prosjektet
        
        fclose(fout);
    end
    
%Del 2************************************************************************
%Creates batch file that runs the .Log file

%Create .bat file
FileBatOut=['D:\Skole\Var 2014\PlaxisCommands\Markov Chain MC\runMCMC.bat'];
        
%Open .bat file
[fbat,errmsg]=fopen(FileBatOut,'wt');

%Check if file is not open
if(fbat<0)
    sprintf('.bat filen er ikke pen.');
    sprintf('Error message. %s', errmsg);
end

if(fbat>=0)
    %Batch commands that runs PLAXIS. (Dir Plaxis - dir prosjekt - kjr
    %.Log-fil)
  
       fprintf(fbat,['"D:\\PLAXIS 2D\\PLAXIS\\Plaxis2DXInput.exe" "C:\\Users\\mordi\\Documents\\PLAXIS\\Leistad.p2dx" "--run=D:\\Skole\\Var 2014\\PlaxisCommands\\Markov Chain MC\\calculate' sprintf('%4.4d',i) '.log"\r\n']);
       fprintf(fbat,['rename C:\\Users\\mordi\\Documents\\PLAXIS\\Leistad.p2dxdat\\data.c01 data' sprintf('%4.4d',i) '.c01 \r\n']); %Denne skal gi nytt navn til en fil...
       fprintf(fbat,['xcopy /s "C:\\Users\\mordi\\Documents\\PLAXIS\\Leistad.p2dxdat\\data' sprintf('%4.4d',i) '.c01" "D:\\Skole\\Var 2014\\PlaxisCommands\\Markov Chain MC\\MCMCResults"\r\n']);
       fprintf(fbat,['del "C:\\Users\\mordi\\Documents\\PLAXIS\\Leistad.p2dxdat\\data' sprintf('%4.4d',i) '.c01"\r\n']);
   
end
fclose(fbat); %Closes .bat file.

%Del 3 ******************************************************************
%Runs .bat file
!D:\Skole\Var 2014\PlaxisCommands\Markov Chain MC\runMCMC.bat

%Del 4 ******************************************************************
%Translates and reads the binary file.

FileOut=['D:\Skole\Var 2014\PlaxisCommands\Markov Chain MC\MCMCResults\translate.bat'];%definerer outputfil
%open outputfile
[fout,errmsg]=fopen(FileOut,'wt'); 
%Check if file is not open
    if(fout<0);
        sprintf('.bat filen er ikke pen.');
        sprintf('Error Message. %s', errmsg);
    end
    %Check if file is open
    if(fout>=0)
        %Opens the folder where rfile.exe is
        fprintf(fout,'cd D:\\Skole\\Var 2014\\PlaxisCommands\\Markov Chain MC\\MCMCResults \r\n');
            %Runs rfile.exe on the file which is to be translated
            fprintf(fout,['rfile.exe data' sprintf('%4.4d',i) '.c01 data' sprintf('%4.4d',i) '.txt \r\n']);
            fprintf(fout,['del "D:\\Skole\\Var 2014\\PlaxisCommands\\Markov Chain MC\\MCMCResults\\data' sprintf('%4.4d',i) '.c01\r\n']);
    end
    
    fclose(fout); %Closes the file
%Runs translate.bat
!D:\Skole\Var 2014\PlaxisCommands\Markov Chain MC\MCMCResults\translate.bat

%Del 5 ********************************************************************
%Reading Safety Factor

%Construct the full file name
folder='D:\Skole\Var 2014\PlaxisCommands\Markov Chain MC\MCMCResults';

        
%Check if file is open
if(fout>=0)
    
%If file is open the FS values are written
baseFileName=['data' sprintf('%4.4d',i) '.txt'];
fullFileName=fullfile(folder,baseFileName);

%if exists, then open it and read FS value
if exist(fullFileName, 'file');
        fid=fopen(fullFileName,'rt');
        %Read line
        LineNum=7501; %Line you are looking for
        c=textscan(fid,'%s','delimiter','\n'); %Reads the line
        line=c{1}{LineNum};
        dummy=sscanf(line,'%d %f');
        FS=dummy(2,1);
        %Then close it
        fclose(fid);
else
    uiwait(msgbox('Fil ikke funnet. Vil du ha en yoghurt istedet? '));
end

%Writes values to result file and jumps to next line (ready for the next
%value)
fprintf(fout1,'%f %f %f %f %f %f %f %f %f \r\n',FS, SU1, SU2, SU3, PAS, DSS, TT1, TT2, TT3);
end

end
%Closes the file
fclose(fout1);
disp('FERDIG!') %Displays this message when the script is finished




